@@ -13,13 +13,11 @@ class DataAccess:
     def __init__(self):
         print ("DataAccess self")
 
-    '''
-    function: query_pg 该方法用于查询pg数据库
-    parameter: 
-              sql-> 查询的sql语句，以分号“;”结尾 
-              spark_context-> spark的上下文  
-    return： 以spark dataFrame的数据结构返回
-    '''
+    # function: query_pg 该方法用于查询pg数据库
+    # parameter:
+    #           sql-> 查询的sql语句，以分号“;”结尾
+    #           spark_context-> spark的上下文
+    # return： 以spark dataFrame的数据结构返回
     @staticmethod
     def query_pg(sql):
         try:
@@ -36,11 +34,9 @@ class DataAccess:
             sys.exit(1)
         return sdf
 
-    '''
-    function: query_hive 查询hive数据库的接口
-    params: sql->查询的sql语句
-    return: 以spark dataFrame的数据结构返回结果集
-    '''
+    # function: query_hive 查询hive数据库的接口
+    # params: sql->查询的sql语句
+    # return: 以spark dataFrame的数据结构返回结果集
     @staticmethod
     def query_hive(sql):
-        return ContextFactory.build_sql_context().sql(sql)
+        return ContextFactory.build_hive_context().sql(sql)
